@@ -169,7 +169,7 @@ sub confNode {
                 # 1. Here, "notranslate" is set to true : hash values must not
                 #    be translated
                 # 2. if a regexp comment exists, it is set as text
-                my $text = ( /^\(\?#(.*)\)/ ? $1 : $_ );
+                my $text = ( /^\(\?#(.*?)\)/ ? $1 : $_ );
                 $res .= $self->li($id)
                   . $self->span(
                     id   => $id,
